emperor.Emperor.make_emperor — Emperor 0.9.51-dev documentation

# emperor.Emperor.make_emperor

`Emperor.` `make_emperor`(standalone=False)

  Build an emperor plot

  Parameters: | standalone : bool Whether or not the produced plot should be a standalone HTML file.
  Returns: | str Formatted emperor plot.

  See also

  `emperor.core.Emperor.copy_support_files`

  Notes

  The `standalone` argument is intended for the different use-cases that Emperor can have, either as an embedded widget that lives inside, for example, the Jupyter notebook, or alternatively as an HTML file that refers to resources locally. In this case you will need to copy the support files by calling the `copy_support_files` method.